@@ -1,5 +1,7 @@
+"""
+    Run the API
+"""
 import click
-
 import spoc
 
 from .shell import shell_command, shell_print
@@ -20,14 +22,14 @@ def run(port, workers):
     # FastAPI-Server
     match mode:
         case "development":
-            run_server = f"python -m uvicorn main:app --reload --port { port }"
+            cmd = f"python -m uvicorn main:app --reload --port { port }"
         case "staging":
-            run_server = f"python -m gunicorn main:app --workers { workers } --worker-class uvicorn.workers.UvicornWorker --bind 0.0.0.0:{ port }"
+            cmd = f"python -m gunicorn main:app --workers { workers } --worker-class uvicorn.workers.UvicornWorker --bind 0.0.0.0:{ port }"
         case "production":
-            run_server = f"python -m gunicorn main:app --workers { workers } --worker-class uvicorn.workers.UvicornWorker --bind 0.0.0.0:{ port }"
+            cmd = f"python -m gunicorn main:app --workers { workers } --worker-class uvicorn.workers.UvicornWorker --bind 0.0.0.0:{ port }"
 
     # Message
     shell_print(f"* Starting FastApi Server... (Mode: { mode.title() })\n")
 
     # RETURN-VALUE
-    shell_command(run_server)
+    shell_command(cmd)
